==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/libroccatwidget/roccat_macro_editor_dialog.h <==
#ifndef __ROCCAT_MACRO_EDITOR_DIALOG_H__
#define __ROCCAT_MACRO_EDITOR_DIALOG_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat/roccat.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_EDITOR_DIALOG_TYPE (roccat_macro_editor_dialog_get_type())
#define ROCCAT_MACRO_EDITOR_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_EDITOR_DIALOG_TYPE, RoccatMacroEditorDialog))
#define IS_ROCCAT_MACRO_EDITOR_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_EDITOR_DIALOG_TYPE))

typedef struct _RoccatMacroEditorDialog RoccatMacroEditorDialog;
typedef struct _RoccatMacroEditorDialogPrivate RoccatMacroEditorDialogPrivate;

struct _RoccatMacroEditorDialog {
	GtkDialog dialog;
	RoccatMacroEditorDialogPrivate *priv;
};

GType roccat_macro_editor_dialog_get_type(void);
void roccat_macro_editor_dialog(GtkWindow *parent);
GtkWidget *roccat_macro_editor_dialog_new(GtkWindow *parent);

void roccat_macro_editor_dialog_add_macros(RoccatMacroEditorDialog *dialog, RoccatMacros *roccat_macros);
RoccatMacros *roccat_macro_editor_dialog_get_macros(RoccatMacroEditorDialog *dialog);

void roccat_macro_editor_dialog_load_macros(RoccatMacroEditorDialog *dialog);
gboolean roccat_macro_editor_dialog_save_macros(RoccatMacroEditorDialog *dialog);

G_END_DECLS

#endif

==> roccat-tools-1.4.0.tar.bz2: roccat-tools-1.4.0/libroccatwidget/roccat_macro_editor_dialog.h <==
#ifndef __ROCCAT_MACRO_EDITOR_DIALOG_H__
#define __ROCCAT_MACRO_EDITOR_DIALOG_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat_macros.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_EDITOR_DIALOG_TYPE (roccat_macro_editor_dialog_get_type())
#define ROCCAT_MACRO_EDITOR_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_EDITOR_DIALOG_TYPE, RoccatMacroEditorDialog))
#define IS_ROCCAT_MACRO_EDITOR_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_EDITOR_DIALOG_TYPE))

typedef struct _RoccatMacroEditorDialog RoccatMacroEditorDialog;
typedef struct _RoccatMacroEditorDialogPrivate RoccatMacroEditorDialogPrivate;

struct _RoccatMacroEditorDialog {
	GtkDialog dialog;
	RoccatMacroEditorDialogPrivate *priv;
};

GType roccat_macro_editor_dialog_get_type(void);
void roccat_macro_editor_dialog(GtkWindow *parent);
GtkWidget *roccat_macro_editor_dialog_new(GtkWindow *parent);

void roccat_macro_editor_dialog_add_macros(RoccatMacroEditorDialog *dialog, RoccatMacros *roccat_macros);
RoccatMacros *roccat_macro_editor_dialog_get_macros(RoccatMacroEditorDialog *dialog);

void roccat_macro_editor_dialog_load_macros(RoccatMacroEditorDialog *dialog);
gboolean roccat_macro_editor_dialog_save_macros(RoccatMacroEditorDialog *dialog);

G_END_DECLS

#endif
